@@ -6,4 +6,4 @@ from pyinter.interval import Interval, open, closed, openclosed, closedopen
 from pyinter.interval_set import IntervalSet
 from pyinter import examples
 
-__all__ = [Interval, open, closed, openclosed, closedopen, IntervalSet, examples]
+__all__ = ['Interval', 'open', 'closed', 'openclosed', 'closedopen', 'IntervalSet', 'examples']
