@@ -1,3 +1,3 @@
 from pyinter.examples.daterange import daterange
 
-__all__ = [daterange]
+__all__ = ['daterange']
